@@ -1,7 +1,7 @@
 // qjackctlAbout.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -26,10 +26,6 @@
 
 #define QJACKCTL_TITLE      PROJECT_TITLE
 
-#define QJACKCTL_SUBTITLE0  "JACK"
-#define QJACKCTL_SUBTITLE1  QJACKCTL_SUBTITLE0 " Audio Connection Kit"
-#define QJACKCTL_SUBTITLE2  "Qt GUI Interface"
-
 #define QJACKCTL_SUBTITLE   PROJECT_DESCRIPTION
 #define QJACKCTL_WEBSITE    PROJECT_HOMEPAGE_URL
 
