@@ -1,7 +1,7 @@
 // qjackctlConnect.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -370,6 +370,9 @@ private:
 
 	// Local instance variables.
 	qjackctlConnectView *m_pConnectView;
+
+	// Connector line color map/persistence.
+	QHash<QString, int> m_colorMap;
 };
 
 
