@@ -1,7 +1,7 @@
 // qjackctlJackGraph.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -81,7 +81,7 @@ protected:
 private:
 
 	// Callback sanity mutex.
-	static QMutex g_mutex;
+	QMutex m_mutex;
 };
 
 
