@@ -1,7 +1,7 @@
 ﻿// qjackctlSetupForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -188,6 +188,8 @@ qjackctlSetupForm::qjackctlSetupForm ( QWidget *pParent )
 	m_ui.InLatencySpinBox->setSpecialValueText(sDefName);
 	m_ui.OutLatencySpinBox->setSpecialValueText(sDefName);
 
+	updatePalette();
+
 	// UI connections...
 
 	QObject::connect(m_ui.PresetComboBox,
@@ -648,7 +650,6 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	// Load font chooser samples...
 	const QString sSansSerif = "Sans Serif";
 	QFont font;
-	QPalette pal;
 
 	if (m_pSetup->sDisplayFont1.isEmpty()
 		|| !font.fromString(m_pSetup->sDisplayFont1))
@@ -667,9 +668,6 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	if (m_pSetup->sMessagesFont.isEmpty()
 		|| !font.fromString(m_pSetup->sMessagesFont))
 		font = QFont("Monospace", 8);
-	pal = m_ui.MessagesFontTextLabel->palette();
-	pal.setColor(QPalette::Window, pal.base().color());
-	m_ui.MessagesFontTextLabel->setPalette(pal);
 	m_ui.MessagesFontTextLabel->setFont(font);
 	m_ui.MessagesFontTextLabel->setText(
 		font.family() + ' ' + QString::number(font.pointSize()));
@@ -677,9 +675,6 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	if (m_pSetup->sConnectionsFont.isEmpty()
 		|| !font.fromString(m_pSetup->sConnectionsFont))
 		font = QFont(sSansSerif, 10);
-	pal = m_ui.ConnectionsFontTextLabel->palette();
-	pal.setColor(QPalette::Window, pal.base().color());
-	m_ui.ConnectionsFontTextLabel->setPalette(pal);
 	m_ui.ConnectionsFontTextLabel->setFont(font);
 	m_ui.ConnectionsFontTextLabel->setText(
 		font.family() + ' ' + QString::number(font.pointSize()));
@@ -1000,7 +995,7 @@ void qjackctlSetupForm::changeCurrentPreset ( const QString& sPreset )
 	// Check if there's any pending changes...
 	if (m_iDirtySettings > 0 && !m_sPreset.isEmpty()) {
 		switch (QMessageBox::warning(isVisible() ? this : parentWidget(),
-			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
+			tr("Warning") + " - " QJACKCTL_TITLE,
 			tr("Some settings have been changed:\n\n"
 			"\"%1\"\n\nDo you want to save the changes?")
 			.arg(m_sPreset),
@@ -1063,7 +1058,7 @@ void qjackctlSetupForm::deleteCurrentPreset (void)
 
 	// Try to prompt user if he/she really wants this...
 	if (QMessageBox::warning(isVisible() ? this : parentWidget(),
-		tr("Warning") + " - " QJACKCTL_SUBTITLE1,
+		tr("Warning") + " - " QJACKCTL_TITLE,
 		tr("Delete preset:\n\n"
 		"\"%1\"\n\nAre you sure?")
 		.arg(sPreset),
@@ -1738,6 +1733,15 @@ void qjackctlSetupForm::resetCustomStyleThemes (
 }
 
 
+void qjackctlSetupForm::updatePalette (void)
+{
+	QPalette pal;
+	pal.setColor(QPalette::Window, pal.base().color());
+	m_ui.MessagesFontTextLabel->setPalette(pal);
+	m_ui.ConnectionsFontTextLabel->setPalette(pal);
+}
+
+
 // Brag about any buffer-size (frames/period) changes...
 void qjackctlSetupForm::buffSizeChanged (void)
 {
@@ -1972,8 +1976,11 @@ void qjackctlSetupForm::apply (void)
 			} else {
 				QPalette pal;
 				if (qjackctlPaletteForm::namedPalette(
-						&m_pSetup->settings(), m_pSetup->sCustomColorTheme, pal))
+						&m_pSetup->settings(), m_pSetup->sCustomColorTheme, pal)) {
 					QApplication::setPalette(pal);
+					pMainForm->updatePalette();
+					updatePalette();
+				}
 			}
 		}
 		// Show restart message if needed...
@@ -2145,7 +2152,7 @@ bool qjackctlSetupForm::queryClose (void)
 	// Check if there's any pending changes...
 	if (m_iDirtySettings > 0 || m_iDirtyOptions > 0 || m_iDirtyBuffSize > 0) {
 		switch (QMessageBox::warning(isVisible() ? this : parentWidget(),
-			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
+			tr("Warning") + " - " QJACKCTL_TITLE,
 			tr("Some settings have been changed.\n\n"
 			"Do you want to apply the changes?"),
 			QMessageBox::Apply |
